"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dalle = void 0;
class Dalle {
    constructor({ apiKey }) {
        this.apiKey = apiKey;
        this.url = "https://labs.openai.com/api/labs/tasks";
    }
    async generate(prompt) {
        const body = {
            task_type: "text2im",
            prompt: { caption: prompt, batch_size: 4 },
        };
        return new Promise(async (resolve, _) => {
            const response = await fetch(this.url, {
                method: "POST",
                headers: {
                    Authorization: `Bearer ${this.apiKey}`,
                    "Content-Type": "application/json",
                },
                body: JSON.stringify(body),
            });
            if (!response.ok) {
                console.error(response);
                return;
            }
            const data = await response.json();
            const taskId = data.id;
            const refreshIntervalId = setInterval(async () => {
                const response = await fetch(`${this.url}/${taskId}`, {
                    headers: {
                        Authorization: `Bearer ${this.apiKey}`,
                        "Content-Type": "application/json",
                    },
                });
                if (!response.ok) {
                    console.error(response);
                    return;
                }
                const data = await response.json();
                if (data.status === "rejected") {
                    clearInterval(refreshIntervalId);
                    resolve(data.status_information);
                }
                else if (data.status === "succeeded") {
                    const generations = data.generations;
                    clearInterval(refreshIntervalId);
                    resolve(generations);
                }
            }, 3000);
        });
    }
}
exports.Dalle = Dalle;
//# sourceMappingURL=index.js.map